django-sites
============

.. image:: https://img.shields.io/travis/niwinz/django-sites.svg?style=flat
    :target: https://travis-ci.org/niwinz/django-sites

.. image:: https://img.shields.io/pypi/v/django-sites.svg?style=flat
    :target: https://pypi.python.org/pypi/django-sites

.. image:: https://img.shields.io/pypi/dm/django-sites.svg?style=flat
    :target: https://pypi.python.org/pypi/django-sites


Alternative implementation of django "sites" framework based on
settings instead of models.


How to install?
---------------

You can install it with pip:

.. code-block:: shell

    pip install django-sites

Documentation
-------------


http://niwinz.github.io/django-sites/latest/
